Scriptname RRR_RentRoomScript extends ReferenceAlias Conditional

MiscObject Property Gold001  Auto

WIFunctionsScript Property WI Auto
{Pointer to WIFunctionsScript attached to WI quest}

Function RentRoom(Int Days = 1, bool PFF = false, bool FreeRoom = false)

	Rent = RoomCostLocal.GetValueInt()
	
	if FreeRoom == True
		Rent = 0
	endif

	FlwerCount = 0
	PayForFollowers = PFF
	if PayForFollowers == True
	
		FlwerCount = (GetOwningQuest() as RRR_QuestScript).CountFollowers()
		
		if RRR_FlwerBedOwnership.GetValue() == 1		
			if FollowerBed01
				FollowerBed01.SetFactionOwner(CurrentFollowerFaction)
			endif
			if FollowerBed02
				FollowerBed02.SetFactionOwner(CurrentFollowerFaction)
			endif
			if FollowerBed03
				FollowerBed03.SetFactionOwner(CurrentFollowerFaction)
			endif			
		else
			if FollowerBed01
				FollowerBed01.SetFactionOwner(None)
			endif
			if FollowerBed02
				FollowerBed02.SetFactionOwner(None)
			endif
			if FollowerBed03
				FollowerBed03.SetFactionOwner(None)
			endif
		endif
	endif
	
	
	if Days <= 0
		; long term rental
		Rolling = True
		MissedPayment = 0
		; take 3 days rent as deposit
		Game.GetPlayer().RemoveItem(Gold001, Rent * 3)
		; and first payment
		Game.GetPlayer().RemoveItem(Gold001, Rent * (FlwerCount + 1))
		; set rolling timer
		RegisterForSingleUpdateGameTime(24.0)
		; used to conditionalize innkeeper dialogue
		Self.GetActorReference().SetActorValue("Variable09", 1.0)	
		; give pc the best room
		Room01Marker.Enable()			
		WI.ShowPlayerRoom(Self.GetActorReference(), Room01Marker)
		
	else
		; short term rental
		Rolling = False
		MissedPayment = 0
		; take payment
		if Days >= 3
			Rent = Rent * (100 - RRR_Discount3Days.GetValueInt()) / 100
		endif
		Game.GetPlayer().RemoveItem(Gold001, Rent * Days * (FlwerCount + 1))
		; set timer
		RegisterForSingleUpdateGameTime(24.0 * Days)
		; used to conditionalize innkeeper dialogue
		Self.GetActorReference().SetActorValue("Variable09", 1.0)
		; pick a random room for pc if more than one available
		if NumOfRooms > 1 && PayForFollowers == False
			int Pick = Utility.RandomInt(1,NumOfRooms)
			if Pick == 1
				Room01Marker.Enable()
				WI.ShowPlayerRoom(Self.GetActorReference(), Room01Marker)
			elseif Pick == 2
				Room02Marker.Enable()
				WI.ShowPlayerRoom(Self.GetActorReference(), Room02Marker)
			elseif Pick == 3
				Room03Marker.Enable()
				WI.ShowPlayerRoom(Self.GetActorReference(), Room03Marker)
			endif
		else
			Room01Marker.Enable()
			WI.ShowPlayerRoom(Self.GetActorReference(), Room01Marker)
		endif

	endif
	
EndFunction

Function ClearRoom()

	if Rolling == True
		; refund deposit
		Game.GetPlayer().AddItem(Gold001, Rent * (3 - MissedPayment))
	endif
	Rolling = False
	esDays = 0
	MissedPayment = 0
	PayForFollowers = False
	FlwerCount = 0

	; reset all rooms
	if Room01Marker
		Room01Marker.Disable()
	endif
	if Room02Marker
		Room02Marker.Disable()
	endif
	if Room03Marker
		Room03Marker.Disable()
	endif
	
	if FollowerBed01
		FollowerBed01.SetFactionOwner(PotentialFollowerFaction)
	endif
	if FollowerBed02
		FollowerBed02.SetFactionOwner(PotentialFollowerFaction)
	endif
	if FollowerBed03
		FollowerBed03.SetFactionOwner(PotentialFollowerFaction)
	endif	
	
	UnregisterForUpdateGameTime()
	Self.GetActorReference().SetActorValue("Variable09", 0.0)

EndFunction

Event OnUpdateGameTime()

	if Rolling == False
		ClearRoom()
	else
		int dRent = Math.Floor(Rent * (100 - 3 * esDays) / 100)
		int MaxDiscount = Math.Floor(Rent * (100 - RRR_DiscountLPatron.GetValue()) / 100)
		if dRent < MaxDiscount
			dRent = MaxDiscount
		endif
		
		Actor PlayerRef = Game.GetPlayer()
		if PlayerRef.GetItemCount(Gold001) >= dRent
			; pay rent
			PlayerRef.RemoveItem(Gold001, dRent * (FlwerCount + 1))
			while MissedPayment > 0 && PlayerRef.GetItemCount(Gold001) >= Rent
				PlayerRef.RemoveItem(Gold001,Rent)
				MissedPayment -= 1
			endWhile
			debug.notification("~"+Self.GetActorReference().getActorBase().getName())
			RRRRentCollected.Show()
			esDays += 1
			RegisterForSingleUpdateGameTime(24.0)
		else
			MissedPayment += 1
			RRRMissedPayment.Show()
			RegisterForSingleUpdateGameTime(24.0)
		endif
		
		if MissedPayment >= 3
			; pc has missed 3 payments, innkeeper isn't happy
			RRRRoomReclaimed.Show()
			ClearRoom()
		endif		
	endif

EndEvent

; if I die, clear the room rental as well, to stop the timer
Event OnDeath(Actor akKiller)
	ClearRoom()
endEvent

int Rent = 50
int FlwerCount = 0
bool PayForFollowers = False
bool Rolling = False
int MissedPayment = 0
int esDays = 0

Int Property NumOfRooms = 1 Auto

GlobalVariable Property RoomCostLocal  Auto
GlobalVariable Property RRR_Discount3Days  Auto
GlobalVariable Property RRR_DiscountLPatron  Auto

GlobalVariable Property RoomCost  Auto
GlobalVariable Property RRR_RoomCost3Days  Auto

ObjectReference Property Room01Marker  Auto
ObjectReference Property Room02Marker  Auto
ObjectReference Property Room03Marker  Auto

ObjectReference Property FollowerBed01  Auto
ObjectReference Property FollowerBed02  Auto
ObjectReference Property FollowerBed03  Auto

GlobalVariable Property RRR_FlwerBedOwnership Auto
Faction Property PotentialFollowerFaction Auto
Faction Property CurrentFollowerFaction Auto

Message Property RRRRentCollected  Auto  
Message Property RRRMissedPayment  Auto  
Message Property RRRRoomReclaimed  Auto




